@@ -333,7 +333,10 @@ def match_actionbindings(party_info, service_binding, service,
             logging.info('Matching action bindings for {} {}'.format(service, action))
 
             if package_id != None:
-                actionbinding_element.set('payloadProfileId', package_id)
+                payload_profile_ref = lxml.etree.SubElement(action_binding,
+                                                            cppa3('PayloadProfileId'))
+
+                payload_profile_ref.text = package_id
                 matched_payload_profiles[package_id] = package_id
 
             ebbp_quality_attributes(thispartyactionbinding,
@@ -712,9 +715,9 @@ def process_encryption(ebms2_security_element, receiver_ebms2_de, mode):
         'cppa2:EncryptionAlgorithm',
         namespaces=_NSMAP
     ):
-        data_encryption_element = lxml.etree.SubElement(encryption_element,
-                                                        cppa3('DataEncryption'))
-        encryption_algorithm_element = lxml.etree.SubElement(data_encryption_element,
+        #data_encryption_element = lxml.etree.SubElement(encryption_element,
+        #                                                cppa3('DataEncryption'))
+        encryption_algorithm_element = lxml.etree.SubElement(encryption_element,
                                                             cppa3('EncryptionAlgorithm'))
         encryption_algorithm_element.text = v2_encryption_algorithm.text
     v2_certificate_ref = receiver_ebms2_de.xpath(
