@@ -185,12 +185,33 @@ def match_service_bindings(cpp, cpp_service_binding, cpa, cpa_service_binding, c
             namespaces=_NSMAP
         )
         if len(cpp_action_binding_list) > 0:
-            cpp_action_binding = cpp_action_binding_list[0]
-            match_action_bindings(cpp, cpp_action_binding, cpa, cpa_action_binding, direction, other_parties)
+            #cpp_action_binding = cpp_action_binding_list[0]
+            #match_action_bindings(cpp, cpp_action_binding, cpa, cpa_action_binding, direction, other_parties)
+            match_cpp_action_binding_for_cpa_element(cpp, cpp_action_binding_list,
+                                                     cpa, cpa_action_binding,
+                                                     direction, other_parties)
         else:
             raise MatchException('No action {} for service {} in CPP'.format(cpa_action, cpa_service))
     # @todo also do the check that all actions that the CPP considers required are present in the CPA
 
+def match_cpp_action_binding_for_cpa_element(cpp, cpp_action_bindings,
+                                             cpa, cpa_action_binding,
+                                             direction, other_parties):
+    for cpp_action_binding in cpp_action_bindings:
+        try:
+            match_action_bindings(cpp, cpp_action_binding, cpa, cpa_action_binding, direction, other_parties)
+        except MatchException as e:
+            logging.info('Skipping CPP action binding {}: {}'.format(
+                cpp_action_binding.get('id'),
+                e.value))
+        else:
+            return
+    # We only get here if no CPP action binding matches
+    raise MatchException('None of the CPP action bindings match for CPA action binding {}'.format(
+        cpa_action_binding.get('id')))
+
+
+
 def match_action_bindings(cpp, cpp_action_binding, cpa, cpa_action_binding, direction, other_parties):
     acl_check(cpp_action_binding, cpp, other_parties)
     match_payload_profiles(cpp, cpp_action_binding, cpa, cpa_action_binding)
@@ -216,30 +237,41 @@ def match_action_bindings(cpp, cpp_action_binding, cpa, cpa_action_binding, dire
     raise MatchException(exception)
 
 def match_payload_profiles(cpp, cpp_action_binding, cpa, cpa_action_binding):
-    cpp_profile_id = cpp_action_binding.get('payloadProfileId')
-    cpa_profile_id = cpa_action_binding.get('payloadProfileId')
-    logging.info('Matching payload profiles {} and {}'.format(cpp_profile_id, cpa_profile_id))
-    if cpp_profile_id == cpa_profile_id == None:
-        pass
-    else:
-        cpp_profile = cpp.xpath('cppa:PayloadProfile[@id="{}"]'.format(cpp_profile_id), namespaces=_NSMAP)[0]
-        cpa_profile = cpa.xpath('cppa:PayloadProfile[@id="{}"]'.format(cpa_profile_id), namespaces=_NSMAP)[0]
-        cpp_part_list = cpp_profile.xpath('child::cppa:PayloadPart', namespaces=_NSMAP)
-        cpa_part_list = cpa_profile.xpath('child::cppa:PayloadPart', namespaces=_NSMAP)
-        cpplen = len(cpp_part_list)
-        cpalen = len(cpa_part_list)
-        if cpplen != cpalen:
-            raise MatchException(
-                'Inconsistent number of payload parts {}: {}; {}: {}'.format(cpp_profile_id,
-                                                                                   cpplen,
-                                                                                   cpa_profile_id,
-                                                                                   cpalen)
-            )
-        else:
-            for c in range(0,cpplen):
-                cpp_part = cpp_part_list[c]
-                cpa_part = cpa_part_list[c]
-                match_payload_part(cpp, cpp_profile_id, cpa, cpa_profile_id, c, cpp_part, cpa_part)
+    #cpp_profile_id = cpp_action_binding.get('payloadProfileId')
+    #cpa_profile_id = cpa_action_binding.get('payloadProfileId')
+
+    cpp_profile_ids = cpp_action_binding.xpath('child::cppa:PayloadProfileId/text()', namespaces=_NSMAP)
+    cpa_profile_ids = cpa_action_binding.xpath('child::cppa:PayloadProfileId/text()', namespaces=_NSMAP)
+
+    if len(cpp_profile_ids) > 0 and len(cpa_profile_ids) > 0:
+        cpa_profile_id = cpa_profile_ids[0]
+        cpp_profile_id = cpp_profile_ids[0]
+
+        for cpp_profile_id in cpp_profile_ids:
+            logging.info('Matching payload profiles {} and {}'.format(cpp_profile_id, cpa_profile_id))
+
+            cpp_profile = cpp.xpath('cppa:PayloadProfile[@id="{}"]'.format(cpp_profile_id), namespaces=_NSMAP)[0]
+            cpa_profile = cpa.xpath('cppa:PayloadProfile[@id="{}"]'.format(cpa_profile_id), namespaces=_NSMAP)[0]
+            cpp_part_list = cpp_profile.xpath('child::cppa:PayloadPart', namespaces=_NSMAP)
+            cpa_part_list = cpa_profile.xpath('child::cppa:PayloadPart', namespaces=_NSMAP)
+            cpplen = len(cpp_part_list)
+            cpalen = len(cpa_part_list)
+            if cpplen != cpalen:
+                raise MatchException(
+                    'Inconsistent number of payload parts {}: {}; {}: {}'.format(cpp_profile_id,
+                                                                                       cpplen,
+                                                                                       cpa_profile_id,
+                                                                                       cpalen)
+                )
+            else:
+                for c in range(0,cpplen):
+                    cpp_part = cpp_part_list[c]
+                    cpa_part = cpa_part_list[c]
+                    match_payload_part(cpp, cpp_profile_id, cpa, cpa_profile_id, c, cpp_part, cpa_part)
+                    return
+        raise MatchException('Unable to match CPA profile {} to CPP profile IDs {}'.format(cpa_profile_id,
+                                                                                           cpp_profile_ids))
+
 
 
 def match_payload_part(cpp, cpp_profile_id, cpa, cpa_profile_id, c, cpp_part, cpa_part):
@@ -415,8 +447,12 @@ def match_simple_child_element(parent_element, child_element):
         namespaces=_NSMAP
     )
     if len(corresponding_elements) > 0:
+        if child_element.text == None:
+            xpq = 'cppa:{}'.format(local_name)
+        else:
+            xpq = 'cppa:{}[text()="{}"]'.format(local_name, child_element.text)
         candidate_matches = parent_element.xpath(
-            'cppa:{}[text()="{}"]'.format(local_name, child_element.text),
+            xpq,
             namespaces=_NSMAP
         )
         if len(candidate_matches) == 0:
