@@ -10,6 +10,7 @@ from inspect import getsourcefile
 from os.path import abspath, dirname, join
 
 from copy import deepcopy
+from catalog import resolve
 
 NSMAP = {'cppa': 'http://docs.oasis-open.org/ebcore/ns/cppa/v3.0' }
 
@@ -28,6 +29,7 @@ class UnifyTestCase( unittest.TestCase ):
             cppa3dir = os.environ['CPPA3XSDDIR']
             cppa3xsd = os.path.join(cppa3dir,'cppa3.xsd')
             xmlschemadoc = lxml.etree.parse(cppa3xsd)
+            xmlschemadoc = resolve(xmlschemadoc, thisdir)
             self.schema = lxml.etree.XMLSchema(xmlschemadoc)
         else:
             # Else no schema validation
@@ -136,7 +138,7 @@ class UnifyTestCase( unittest.TestCase ):
         logging.info('------------------------------------------')
 
     """
-    General tests using NamedProtocolBinding
+    General tests using NamedChannel
     """
 
     # One Service with complementary Roles one matching Action, matching send-receive, success
@@ -317,6 +319,15 @@ class UnifyTestCase( unittest.TestCase ):
         self.do_unification('0085')
 
 
+    # Multiple entries for a Service / Action combination
+    # In unification a compatible option is to be found
+    def test_0090(self):
+        self.do_unification('0090')
+
+    def test_0091(self):
+        self.do_unification('0091')
+
+
 
     """
     Payload Profile
@@ -360,6 +371,19 @@ class UnifyTestCase( unittest.TestCase ):
     def test_0107(self):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0107')
 
+    # A supports two versions,  newest preferred.  B only supports oldest
+    def test_0120(self):
+        self.do_unification('0120')
+
+    # A supports two versions,  newest preferred.  B only supports newest
+    def test_0121(self):
+        self.do_unification('0121')
+
+    # A supports two versions,  newest preferred.  B also supports both but prefers oldest
+    def test_0122(self):
+        self.do_unification('0122')
+
+
     # Payload signature
     def test_0110(self):
         self.do_unification('0110')
@@ -1055,6 +1079,10 @@ class UnifyTestCase( unittest.TestCase ):
     def test_1622(self):
         self.do_unification('1622', handle_defaults=True, agreementidfun=entsog_agreementref)
 
+    def test_1625(self):
+        self.do_unification('1625', handle_defaults=True, agreementidfun=entsog_agreementref)
+
+
     # SuperAnnuation
     # As defined in DATA AND PAYMENT STANDARDS
     # MESSAGE ORCHESTRATION AND PROFILES
@@ -1525,15 +1553,48 @@ class UnifyTestCase( unittest.TestCase ):
     def test_5006(self):
         self.do_unification('5006')
 
+    # Like 5006,  elaborated with payload profile, alternatives
+    def test_5007(self):
+        self.do_unification('5007')
+
     # Version of test 3400 using a delegation channel
     def test_5100(self):
         self.do_unification('5100')
 
 
     """
-    ebCore Connect
+    Future transports and messaging protocols
     """
 
+    # Simple AMQP message with AQMP transport
+    def test_6000(self):
+        self.do_unification('6000')
+
+    # Simple AMQP message with AQMP transport and a TLS tunnel
+    def test_6001(self):
+        self.do_unification('6001')
+
+    # Simple AMQP message with AQMP transport, anonymous SASL mechanism
+    def test_6002(self):
+        self.do_unification('6002')
+
+    # Simple AMQP message with AQMP transport, intersection of SASL mechanisms
+    def test_6003(self):
+        self.do_unification('6003')
+
+    # Simple AMQP message with AQMP transport and SASL and an in-protocol TLS upgrade
+    def test_6004(self):
+        self.do_unification('6004')
+
+    """
+    Future transport bindings
+    """
+
+    # Hypothetical ebMS3 binding that uses SFTP
+    def test_6200(self):
+        self.do_unification('6200')
+
+
 
     """
     Tests for lower level functions
